@@ -628,6 +628,7 @@ def derivative_history_virgin(symbol,start_date,end_date,instrumentType,expiry_d
     logging.info(nsefetch_url)
     logging.info(payload)
     return pd.DataFrame.from_records(payload["data"])
+
 def derivative_history(symbol,start_date,end_date,instrumentType,expiry_date,strikePrice="",optionType=""):
     #We are getting the input in text. So it is being converted to Datetime object from String.
     start_date = datetime.datetime.strptime(start_date, "%d-%m-%Y")
@@ -925,4 +926,10 @@ def nse_expirydetails_by_symbol(symbol,meta ="Futures",i=0):
     currentExpiry=expiry_dates[i]
     currentExpiry = datetime.datetime.strptime(currentExpiry,'%d-%b-%Y').date()    
     dte = (currentExpiry - datetime.datetime.now().date()).days
-    return currentExpiry,dte
\ No newline at end of file
+    return currentExpiry,dte
+
+def security_wise_archive(from_date, to_date, symbol, series="ALL"):   
+    base_url = "https://www.nseindia.com/api/historical/securityArchives"
+    url = f"{base_url}?from={from_date}&to={to_date}&symbol={symbol.upper()}&dataType=priceVolumeDeliverable&series={series.upper()}"
+    payload = nsefetch(url)
+    return pd.DataFrame(payload['data'])
\ No newline at end of file
